###################################################
### chunk number 1: 
###################################################
options("digits.secs"=6)
dyn.load("reuters_ts.dll")

init <- function(
  serviceName="IDN_SELECTFEED", 
  configPath="sslapi.cnf",
  appId="R.reuters-client", 
  serverName="lonmdddist1 lonmdddist2") {
    .Call("init", serviceName, configPath, appId, serverName)
}


###################################################
### chunk number 2: 
###################################################
fetch <- function(code="EUR=", n=0, t="d", sd=NULL, ed=NULL, rev=TRUE, debug=FALSE) {
    if (!is.null(sd)) {
        if (is.null(ed)) {
            ed <- format((Sys.Date()), format="%m/%d/%Y")       
        }
    }

    if (debug) {
        print(paste("fetch(code=",code,",n=",n,",sd=",sd,",ed=",ed,")"))
    }
    frame <- data.frame(.Call("fetch", code, n, t, sd, ed, debug))
    frame$Date <- as.Date(strptime(frame$Date, "%m/%d/%Y"))
    if (rev) {
        frame <- frame[ order(frame$Date), ]
    }
    frame
}

init()


###################################################
### chunk number 3: 
###################################################
gbp.m <- fetch("GBP=", n=1000, t="m")
gbp.w <- fetch("GBP=", n=1000, t="w")
gbp.d <- fetch("GBP=", n=1000, t="d")
head(gbp.m)
head(gbp.w)
head(gbp.d)


###################################################
### chunk number 4: 
###################################################
msft.vol <- fetch("MSFT.O",sd="1/1/2008",ed="10/31/2008")
layout(matrix(c(1,1,1,1,2,2), 3, 2, T))
plot(msft.vol$Date, msft.vol$CLS, main="MSFT Close Price", type="l", ylab="", xlab="Date")
plot(msft.vol$Date, msft.vol$VOL, main="Volume", type='h', ylab="", xlab="")


###################################################
### chunk number 5: 
###################################################
fed.discount <- fetch("USDISC=", sd="1/1/2007" ,t="m")
plot(fed.discount$Date, fed.discount$CLS, main="Federal Discount Rate", 
 type="l", lwd=2, xaxt="n", ylab="Discount Rate (%)", las=2)
axis.Date(1, at=seq(fed.discount$Date[1], 
 fed.discount$Date[length(fed.discount$Date)], "3 months"), format="%m-%Y") 


###################################################
### chunk number 6: 
###################################################
gbprime <- fetch("GBPRIME=", sd="1/1/2006", ed="12/5/2008", t="d")
plot(gbprime$Date[-1], diff(gbprime$CLS), type='h', lwd=2, ylab="Change in Prime Rate(%)", 
 col=ifelse(diff(gbprime$CLS) < 0, 'red', 'green'), main="Changes in UK Prime Rate")


###################################################
### chunk number 7: 
###################################################
libor.3m <- fetch("GBP3MFSR=", sd="1/1/2007", ed="12/1/2008", t="d")
plot(libor.3m$Date, libor.3m$CLS, type="l", main="3M LIBOR", ylab="3m LIBOR")


###################################################
### chunk number 8: 
###################################################
usd.libor3m <- fetch("USD3MFSR=", sd="1/1/2007", ed="12/1/2008", t="d")
eur.libor3m <- fetch("EUR3MFSR=", sd="1/1/2007", ed="12/1/2008", t="d")
plot(usd.libor3m$Date, usd.libor3m$CLS, type="l", 
 ylim=range(usd.libor3m$CLS,eur.libor3m$CLS),main="USD/EUR 3m LIBOR",ylab="3m LIBOR (%)")
lines(eur.libor3m$Date, eur.libor3m$CLS, lty=2)
legend("bottomleft", legend=c("USD 3m LIBOR", "EUR 3m LIBOR"), lty=c(1,2))


###################################################
### chunk number 9: 
###################################################
codes <- c("RBSL","ABBL","JPML")
tenors <- c("GBPONFSR=","GBPSWFSR=","GBP2WFSR=","GBP1MFSR=","GBP3MFSR=","GBP4MFSR=","GBP5MFSR=","GBP6MFSR=","GBP1YFSR=")
rics <- apply(expand.grid(tenors,codes),1,function(x) paste(x,collapse=""))
rbs.libor <- sapply( rics[grep("RBSL",rics)], function(x) fetch(x, n=1) )
jpm.libor <- sapply( rics[grep("JPML",rics)], function(x) fetch(x, n=1) )
abby.libor <- sapply( rics[grep("ABBL",rics)], function(x) fetch(x, n=1) )
yrange <- range(unlist(rbs.libor[2,]),unlist(jpm.libor[2,]),unlist(abby.libor[2,]))
plot(1:length(rbs.libor[2,]), unlist(rbs.libor[2,]), xaxt="n", type='o', main="Contributed LIBOR Rates", 
 ylab="LIBOR (%)", ylim=yrange, xlab="Tenor")
lines(1:length(abby.libor[2,]), unlist(abby.libor[2,]),type='o', col=2)
lines(1:length(jpm.libor[2,]), unlist(jpm.libor[2,]),type='o', col=3)
axis(1,labels=unique(sub("GBP(\\w\\w).*","\\1",rics)),at=1:length(rbs.libor[2,]))
legend("bottomright", legend=c("RBS","Abbey","JPM"), col=1:3, lty=1)


###################################################
### chunk number 10: 
###################################################
ted <- fetch("TED", sd="1/1/2006", t="d")
max(ted$CLS)
plot(ted$Date, ted$CLS, main="TED Spread", type="l", ylab="Ted Spread (bps)")


###################################################
### chunk number 11: 
###################################################
abx.aaa <- fetch("ABXAA38FGB=MP", sd="1/1/2007", ed="12/1/2008", t="d")
abx.bbb <- fetch("ABXBM38FGB=MP", sd="1/1/2007", ed="12/1/2008", t="d")
op <- par(mfcol=c(2,1),las=2)
plot(abx.aaa$Date, abx.aaa$BID, type="l" ,main="ABX HE AAA 7-2",  ylab="Price", xaxt="n")
axis.Date(1, at=seq(abx.aaa$Date[1], abx.aaa$Date[length(abx.aaa$Date)], "2 months"), format="%m/%Y") 
plot(abx.bbb$Date, abx.bbb$BID, type="l" ,main="ABX HE BBB- 7-2",  ylab="Price", xaxt="n") 
axis.Date(1, at=seq(abx.bbb$Date[1], abx.bbb$Date[length(abx.aaa$Date)], "2 months"), format="%m/%Y") 
par(op)


###################################################
### chunk number 12: 
###################################################
vix <- fetch(".VIX", sd="1/1/2007")
plot(vix$Date, vix$CLS, type="l", main="VIX" ,ylab="VIX Index")


###################################################
### chunk number 13: 
###################################################
library(zoo)
aaa10y <- fetch("AAAUSD10Y=", n=600, t="d")
bbb10y <- fetch("BBBUSD10Y=", n=600, t="d")
ust10y <- fetch("US10YT=RR", n=600, t="d")

aaa10y.series <- zoo(aaa10y, order.by=aaa10y$Date)
bbb10y.series <- zoo(bbb10y, order.by=bbb10y$Date)
ust10y.series <- zoo(ust10y, order.by=ust10y$Date)

full.series <- merge(aaa10y.series, bbb10y.series, ust10y.series, all=FALSE)

ylims <- range(aaa10y$CYLD, bbb10y$CYLD, ust10y$CYLD)
plot(index(full.series), full.series$CYLD.ust10y.series, type="l", ylim=ylims, main="10 Year AAA/BBB/US Treasury Yields", ylab="Yield")
lines(index(full.series), full.series$CYLD.aaa10y.series, lty=2)
lines(index(full.series), full.series$CYLD.bbb10y.series, lty=3)

legend("bottomleft", lty=c(1,2,3), legend=c("10Y UST","AAA Corporate", "BBB Corporate"))


